colour.constants.cie Module — Colour 0.3.0 documentation

# colour.constants.cie Module

## CIE Constants

Defines CIE constants.

`colour.constants.cie.` `CIE_E` = 0.008856451679035631

  CIE \(\epsilon\) constant.

  CIE_E : numeric

  Notes

  - The original CIE value for \(\epsilon\) is \(\epsilon=0.008856\), Bruce Lindbloom has shown that this value is causing a discontinuity a the junction point of the two functions grafted together to create the Lightness \(L^*\) function.

    That discontinuity can be avoided by using the rational representation as follows: \(\epsilon=216/24389\).

  References

  [1] | http://brucelindbloom.com/index.html?LContinuity.html (Last accessed 24 February 2014)

`colour.constants.cie.` `CIE_K` = 903.2962962962963

  CIE \(k\) constant.

  CIE_K : numeric

  Notes

  - The original CIE value for \(k\) is \(k=903.3\), Bruce Lindbloom has shown that this value is causing a discontinuity a the junction point of the two functions grafted together to create the Lightness \(L^*\) function.

    That discontinuity can be avoided by using the rational representation as follows: \(k=24389/27\).

  References

  [2] | http://brucelindbloom.com/index.html?LContinuity.html (Last accessed 24 February 2014)